import { useEffect, useState } from 'react'
import { useLocation } from 'react-router-dom'
import { Tabs, Dropdown, Space, Modal, Button, Form, Input, message } from 'antd'
import { CaretDownOutlined, ExclamationCircleFilled } from '@ant-design/icons'
import type { TabsProps, MenuProps } from 'antd'
import sso from '@src/lib/http/sso'
import router from '@src/router/router'
import styles from './index.module.css'
import { debounce } from 'lodash'
import { getAgencyInfo } from '@src/lib/http/api'
import http from '@src/lib/http/index'
import { useGlobalStateUpdate } from '@src/store/globalStates/userState'

const { confirm } = Modal


function Nav() {
  const [showModal, setShowModal] = useState(false)
  const [current, setCurrent] = useState('/ad-manage')
  const [userInfo, setUserInfo] = useState<UserInfoType>()
  const location = useLocation()
  const setUserState = useGlobalStateUpdate()

  useEffect(() => {
    fetchUserInfo()
  }, [])

  function fetchUserInfo() {
    http.get(getAgencyInfo).then(res => {
      const { data } = res
      setUserInfo(data as UserInfoType)
      setUserState(data as UserInfoType)
    })
  }

  useEffect(() => {
    const { pathname } = location || {}
    if (pathname) {
      setCurrent(pathname)
    }
  }, [location])

  function onTabClick(key: string) {
    setCurrent(key)
    router.navigate(key)
  }

  function logout() {
    confirm({
      title: '确认退出广告平台吗？',
      icon: <ExclamationCircleFilled />,
      onOk() {
        sso.logout()
      },
      okText: '确认',
      cancelText: '取消',
      onCancel() {},
    })
  }

  function editPassword() {
    setShowModal(true)
  }

  function formSubmit() {
    setShowModal(false)
  }

  const tabItems: TabsProps['items'] = [
    // {
    //   label: '推广',
    //   key: '/ad-manage',
    // },
    // {
    //   label: '广告主',
    //   key: '/advertiser',
    // },
    // {
    //   label: '文档',
    //   key: '/documentation',
    // }
  ]

  const items: MenuProps['items'] = [
    {
      label: <p onClick={editPassword}>修改密码</p>,
      key: '3',
    },
    {
      type: 'divider',
    },
    {
      label: <p onClick={logout}>退出登录</p>,
      key: '4',
    },
  ]

  return (
    <header id={styles.header}>
      <div className={styles['nav-contianer']}>
        <div className={styles['logo-contianer']}>
          <div className={styles['logo-icon']}></div>
          <div className={styles['logo-title']}>
            票圈 <span>|</span> 广告联盟
          </div>
        </div>
        <div className={styles['tabs-contianer']}>
          <Tabs onTabClick={(key) => onTabClick(key)} activeKey={current} items={tabItems} />
        </div>
        <div className={styles['user-contianer']}>
          <div className={styles['user-info']}>
            <Dropdown menu={{ items }} trigger={['click']}>
              <a className={styles['user-name']} onClick={(e) => e.preventDefault()}>
                <Space>
                  { userInfo?.company }
                  <CaretDownOutlined />
                </Space>
              </a>
            </Dropdown>
          </div>
        </div>
      </div>

      <ChangePasswordModal open={showModal} formSubmit={formSubmit} onCancel={() => setShowModal(false)} />
    </header>
  )
}

type ChangePasswordType = {
  open: boolean
  formSubmit(): void
  onCancel(): void
}

function ChangePasswordModal({ open, formSubmit, onCancel }: ChangePasswordType) {
  const [form] = Form.useForm()

  function submit() {
    form.validateFields().then(res => {
      const { oldPassword, newPassword, checkNewPassword } = res

      if (newPassword !== checkNewPassword) {
        message.error('两次密码输入不一致，请重新输入')
        return
      }

      fetchChangeLoginPassword(oldPassword, newPassword)
    }).catch(()=>{})
  }

  const fetchChangeLoginPassword = debounce((oldPassword, newPassword) => {
    sso.changeLoginPassword(oldPassword, newPassword).then(res => {
      res && formSubmit()
    })
  }, 500)

  const afterOpenChange = (open:boolean) => {
    if (!open)
      form.resetFields()
  }

  return (
    <Modal
      title='修改密码'
      centered
      open={open}
      onCancel={onCancel}
      footer={null}
      wrapClassName={styles['advertiser-modal']}
      afterOpenChange={afterOpenChange}
    >
      <Form form={form}>
        <Form.Item name='oldPassword' label='请输入原密码' rules={[{ required: true, message: '请输入原密码' }]}>
          <Input.Password placeholder='请输入原密码' allowClear />
        </Form.Item>
        <Form.Item name='newPassword' label='请输入新密码' rules={[{ required: true, message: '请输入新密码' }]}>
          <Input.Password placeholder='请输入新密码' allowClear />
        </Form.Item>
        <Form.Item name='checkNewPassword' label='请确认新密码' rules={[{ required: true, message: '请确认新密码' }]}>
          <Input.Password placeholder='请确认新密码' allowClear />
        </Form.Item>
        <Form.Item name='loginBtn'>
          <Button type="primary" block onClick={submit}>确认</Button>
        </Form.Item>
      </Form>
    </Modal>
  )
}

export default Nav
